@@ -1,13 +1,11 @@
 import click
 
 from adam.commands.command import Command
-from adam.commands.command_helpers import ClusterCommandHelper
 from .medusa_backup import MedusaBackup
 from .medusa_restore import MedusaRestore
 from .medusa_show_backupjobs import MedusaShowBackupJobs
 from .medusa_show_restorejobs import MedusaShowRestoreJobs
 from adam.repl_state import ReplState, RequiredState
-from adam.utils import lines_to_tabular, log, log2
 
 class Medusa(Command):
     COMMAND = 'medusa'
@@ -31,20 +29,7 @@ class Medusa(Command):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
 
-        state, args = self.apply_state(args, state)
-        if not self.validate_state(state):
-            return state
-
-        if state.in_repl:
-            log(lines_to_tabular([c.help(ReplState()) for c in Medusa.cmd_list()], separator=':'))
-
-            return 'command-missing'
-        else:
-            # head with the Chain of Responsibility pattern
-            cmds = Command.chain(Medusa.cmd_list())
-            if not cmds.run(cmd, state):
-                log2('* Command is missing.')
-                Command.display_help()
+        return super().intermediate_run(cmd, state, args, Medusa.cmd_list())
 
     def cmd_list():
         return [MedusaBackup(), MedusaRestore(), MedusaShowBackupJobs(), MedusaShowRestoreJobs()]
@@ -55,15 +40,6 @@ class Medusa(Command):
 
         return {}
 
-    def help(self, _: ReplState):
-        return None
-
 class MedusaCommandHelper(click.Command):
     def get_help(self, ctx: click.Context):
-        log(super().get_help(ctx))
-        log()
-        log('Sub-Commands:')
-
-        log(lines_to_tabular([c.help(ReplState()).replace(f'{Medusa.COMMAND} ', '  ', 1) for c in Medusa.cmd_list()], separator=':'))
-        log()
-        ClusterCommandHelper.cluster_help()
\ No newline at end of file
+        Command.intermediate_help(super().get_help(ctx), Medusa.COMMAND, Medusa.cmd_list(), show_cluster_help=True)
\ No newline at end of file
