@@ -61,26 +61,30 @@ def enter_repl(state: ReplState):
         return f"{msg}$ " if state.bash_session else f"{msg}> "
 
     Log.log2(f'kaqing {__version__}')
-    ss = StatefulSets.list_sts_name_and_ns()
 
     if state.device == ReplState.C:
+        ss = StatefulSets.list_sts_name_and_ns()
         if not ss:
             raise Exception("no Cassandra clusters found")
-        elif len(ss) == 1 and Config().get('repl.auto-enter-only-cluster', True):
+        elif not state.sts and len(ss) == 1 and Config().get('repl.auto-enter-only-cluster', True):
             cluster = ss[0]
             state.sts = cluster[0]
             state.namespace = cluster[1]
-            Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}@{state.namespace}...')
+            if KubeContext().in_cluster_namespace:
+                Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}...')
+            else:
+                Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}@{state.namespace}...')
     elif state.device == ReplState.A:
-        if app := Config().get('repl.auto-enter-app', 'c3/c3'):
-            if app != 'no':
-                ea = app.split('/')
-                state.app_env = ea[0]
-                if len(ea) > 1:
-                    state.app_app = ea[1]
-                    Config().wait_log(f'Moving to {state.app_env}/{state.app_app}...')
-                else:
-                    Config().wait_log(f'Moving to {state.app_env}...')
+        if not state.app_env:
+            if app := Config().get('repl.auto-enter-app', 'c3/c3'):
+                if app != 'no':
+                    ea = app.split('/')
+                    state.app_env = ea[0]
+                    if len(ea) > 1:
+                        state.app_app = ea[1]
+                        Config().wait_log(f'Moving to {state.app_env}/{state.app_app}...')
+                    else:
+                        Config().wait_log(f'Moving to {state.app_env}...')
 
     kb = KeyBindings()
 
@@ -105,8 +109,9 @@ def enter_repl(state: ReplState):
                         completions = deep_sort_dict(deep_merge_dicts(completions, cmd.completion(state)))
                     finally:
                         if Config().get('debugs.timings', False):
-                            Config().debug('Timing completion calc', cmd.command(), f'{time.time() - s1:.2f}')
+                            log2(f'Timing auto-completion-calc {cmd.command()}: {time.time() - s1:.2f}')
 
+                # print(json.dumps(completions, indent=4))
                 completer = NestedCompleter.from_nested_dict(completions)
 
             cmd = session.prompt(prompt_msg(), completer=completer, key_bindings=kb)
@@ -153,7 +158,7 @@ def enter_repl(state: ReplState):
         finally:
             Config().clear_wait_log_flag()
             if Config().get('debugs.timings', False) and 'cmd' in locals() and 's0' in locals():
-                print('Timing command', cmd, f'{time.time() - s0:.2f}')
+                log2(f'Timing command {cmd}: {time.time() - s0:.2f}')
 
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterCommandHelper, help="Enter interactive shell.")
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
