@@ -1,5 +1,6 @@
 import copy
 from enum import Enum
+import re
 
 from adam.commands.postgres.postgres_session import PostgresSession
 from adam.k8s_utils.cassandra_clusters import CassandraClusters
@@ -128,8 +129,30 @@ class ReplState:
             if index < 6:
                 state = copy.copy(state)
 
-                if arg in [f'{ReplState.A}:', f'{ReplState.C}:', f'{ReplState.P}:']:
-                    state.device = arg.strip(':')
+                groups = re.match(r'^([a|c|p]):(.*)$', arg)
+                if groups:
+                    if groups[1] == 'p':
+                        state.device = 'p'
+                        state.pg_path = groups[2]
+                    elif groups[1] == 'c':
+                        state.device = 'c'
+                        if path := groups[2]:
+                            p_and_ns = path.split('@')
+                            sts_and_pod = p_and_ns[0].split('/')
+                            state.sts = sts_and_pod[0]
+                            if len(sts_and_pod) > 1:
+                                state.pod = sts_and_pod[1]
+                            if len(p_and_ns) > 1:
+                                state.namespace = p_and_ns[1]
+                            elif ns := KubeContext.in_cluster_namespace():
+                                state.namespace = ns
+                    else:
+                        state.device = 'a'
+                        if path := groups[2]:
+                            env_and_app = path.split('/')
+                            state.app_env = env_and_app[0]
+                            if len(env_and_app) > 1:
+                                state.app_app = env_and_app[1]
                 else:
                     new_args.append(arg)
             else:
